@@ -4,6 +4,12 @@
 #include "vector_functions.h"
 #include "rolls/sided_dice.h"
 
+
+// #ifdef __cplusplus
+// extern "C" {
+// #endif
+
+
 typedef enum {
     NO_MOCK=0,
     RETURN_CONSTANT=1,
@@ -14,6 +20,11 @@ typedef enum {
 
 int roll(char * s);
 int roll_and_write(char * s, char * f);
-int mock_roll(char * s, char * f, int mock_value, int quiet, int mock_const);
+int mock_roll(char * s, char * f, int mock_value, int mock_const);
+
+
+// #ifdef __cplusplus
+// }
+// #endif
 
 #endif
